# freedb scraper
#
# Copyright  1999-2011 Readerware Corporation.  All Rights Reserved.

import  os
import  string

import  aw

from    com.readerware.http import HTTPConnection

from    rwsupport import searchFor
from    rwsupport import searchForPlus
from    rwsupport import stripText
from    rwsupport import convertArtist

from    jarray import zeros, array
from    java.lang import String
from    java.util import Date


def extract(source):
    # Find track times
    timeList = []
    i = string.find(source, "Track frame offsets:")

    if i != -1:
        running = searchForPlus(source, "Track frame offsets:")
        i = string.find(running, "Disc length:")
        running = stripText(running[0:i])

        running = searchForPlus(running, "#")
        i = string.find(running, "#")
        startFrame = stripText(running[0:i])

        while (string.find(running, "#") != -1):
            running = searchForPlus(running, "#")
            i = string.find(running, "#")
            trackTime = stripText(running[0:i])

            if trackTime != "":
                timeList.append(trackTime)

    # Find running time
    i = string.find(source, "Disc length:")

    if i != -1:
        running = searchForPlus(source, "Disc length:")
        i = string.find(running, "\n")
        running = stripText(running[0:i])
        i = string.find(running, " ")

        if i != -1:
            running = stripText(running[0:i])

        try:
            secs = string.atoi(running)
            frame = "%d" % ((secs * 75) + 75)
            timeList.append(frame)
            mins = secs / 60
            secs = secs % 60
            mins = "%02d" % mins
            secs = "%02d" % secs
            running = mins + ":" + secs
        except:
            running = running + " seconds"



    # Find Artist / Title
    source = searchForPlus(source, "DTITLE=")
    i = string.find(source, "\n")
    artist = stripText(source[0:i])

    i = string.rfind(artist, "/")

    if i != -1:
        title = artist[i+1:]
        artist = artist[0:i]
    else:
        title = artist
        artist = "Various"

    aw.setTitle(title)
    aw.setArtist(artist)


    # Find copyright date
    i = string.find(source, "DYEAR=")

    if i != -1:
        copyDate = searchForPlus(source, "DYEAR=")
        i = string.find(copyDate, "\n")
        aw.setCopyrightDate(stripText(copyDate[0:i]))


    # Find Category
    i = string.find(source, "DGENRE=")

    if i != -1:
        category = searchForPlus(source, "DGENRE=")
        i = string.find(category, "\n")
        aw.setCategory1(stripText(category[0:i]))


    # Find Tracks
    # No multi disk sets, freedb lists CDs separately
    i = string.find(source, "TTITLE0=")

    if (i != -1):
        source = searchFor(source, "TTITLE0=")
        i = string.find(source, "EXTD=")
        tracks = stripText(source[0:i]) + "\n"
        diskCount = 1
        trackNum = 0

        while (string.find(tracks, "=") != -1):
            tracks = searchFor(tracks, "TTITLE")
            i = string.find(tracks, "=")
            key = stripText(tracks[0:i])
            tracks = searchForPlus(tracks, "=")
            i = string.find(tracks, "\n")
            track = stripText(tracks[0:i])

            # Tracks can span multiple lines, you could see multiple 
            # TTITLE2= lines for example. Get all track title lines
            while (string.find(tracks, "=") != -1):
                nexttrack = searchFor(tracks, "TTITLE")
                i = string.find(nexttrack, "=")
                nextkey = stripText(nexttrack[0:i])

                if key != nextkey:
                    break

                tracks = searchForPlus(tracks, "=")
                i = string.find(tracks, "\n")
                track = track + stripText(tracks[0:i])

            artist = ""
            time = timeList[trackNum]
            trackNum = trackNum + 1

            try:
                fromF = string.atoi(startFrame)
                startFrame = time
                toF = string.atoi(time)
                secs = (toF - fromF) / 75
                mins = secs / 60
                secs = secs % 60
                mins = "%d" % mins
                secs = "%02d" % secs
                time = mins + ":" + secs
            except:
                time = ""

            aw.setTrack(diskCount, trackNum, track, artist=artist, time=time)



try:
    aw.setAlbumObject(Album)
    extract(source)
finally:
    if os.path.exists(aw.getDocsDir() + "awuserexit.py"):
        execfile(aw.getDocsDir() + "awuserexit.py") in globals()
